@@ -451,6 +451,12 @@ class Nominations(Model):
     current: int
     required: int
 
+class Nomination(Model):
+    beatmapset_id: int
+    rulesets: List[GameMode]
+    reset: bool
+    user_id: int
+
 class Kudosu(Model):
     total: int
     available: int
@@ -530,6 +536,10 @@ class ForumPostBody(Model):
 class ReviewsConfig(Model):
     max_blocks: int
 
+class RankHighest(Model):
+    rank: int
+    updated_at: Datetime
+
 
 # ===================
 # Undocumented Models
