@@ -13,7 +13,7 @@ from ossapi.enums import (UserAccountHistory, ProfileBanner, UserBadge, Country,
     EventBeatmap, BeatmapsetApproval, EventBeatmapset, KudosuVote,
     BeatmapsetEventType, UserRelationType, UserLevel, UserGradeCounts,
     GithubUser, ChangelogSearch, ForumTopicType, ForumPostBody, ForumTopicSort,
-    ChannelType, ReviewsConfig, NewsSearch)
+    ChannelType, ReviewsConfig, NewsSearch, Nomination, RankHighest)
 from ossapi.utils import Datetime, Model, BaseModel, Field
 
 T = TypeVar("T")
@@ -172,6 +172,8 @@ class User(UserCompact):
     twitter: Optional[str]
     website: Optional[str]
     scores_pinned_count: int
+    nominated_beatmapset_count: int
+    rank_highest: RankHighest
 
     def expand(self) -> User:
         # we're already expanded, no need to waste an api call
@@ -228,6 +230,12 @@ class Beatmap(BeatmapCompact):
     playcount: int
     ranked: RankStatus
     url: str
+    # user associated with this difficulty (ie diff mapper / owner).
+    # Returned as `user` in the api, but that conflicts with our fk method for
+    # beatmapset owner.
+    # This is optional as a workaround until
+    # https://github.com/ppy/osu-web/issues/9784 is resolved.
+    owner: Optional[UserCompact] = Field(name="user")
 
     # overridden fields
     # -----------------
@@ -308,6 +316,7 @@ class Beatmapset(BeatmapsetCompact):
     storyboard: bool
     submitted_date: Optional[Datetime]
     tags: str
+    current_nominations: Optional[List[Nomination]]
 
     def expand(self) -> Beatmapset:
         return self
@@ -345,10 +354,14 @@ class Score(Model):
     weight: Optional[Weight]
     _user: Optional[UserCompact] = Field(name="user")
     match: Optional[Match]
+    type: str
 
     def user(self) -> Union[UserCompact, User]:
         return self._fk_user(self.user_id, existing=self._user)
 
+    def download(self):
+        return self._api.download_score(self.mode, self.id)
+
 class BeatmapUserScore(Model):
     position: int
     score: Score
@@ -763,6 +776,7 @@ class MultiplayerScoresCursor(Model):
 
 class NewsListing(Model):
     cursor: CursorT
+    cursor_string: str
     news_posts: List[NewsPost]
     news_sidebar: NewsSidebar
     search: NewsSearch
@@ -787,7 +801,7 @@ class NewsNavigation(Model):
 class NewsSidebar(Model):
     current_year: int
     news_posts: List[NewsPost]
-    years: list[int]
+    years: List[int]
 
 class SeasonalBackgrounds(Model):
     ends_at: Datetime
@@ -849,6 +863,7 @@ class BeatmapsetDiscussions(Model):
     reviews_config: ReviewsConfig
     users: List[UserCompact]
     cursor_string: Optional[str]
+    beatmapsets: List[Beatmapset]
 
 class BeatmapsetDiscussionReview(Model):
     # https://github.com/ppy/osu-web/blob/master/app/Libraries/BeatmapsetDiscussionReview.php
@@ -1039,14 +1054,13 @@ class UserStatistics(Model):
     replays_watched_by_others: int
     is_ranked: bool
     grade_counts: UserGradeCounts
-
-    # optional fields
-    # ---------------
     country_rank: Optional[int]
     global_rank: Optional[int]
     rank: Optional[Any]
     user: Optional[UserCompact]
     variants: Optional[Any]
+    global_rank_exp: Optional[float]
+    pp_exp: float
 
 class UserStatisticsRulesets(Model):
     # undocumented
