@@ -1,7 +1,7 @@
 from unittest import TestCase
 
 from ossapi import (RankingType, BeatmapsetEventType, AccessDeniedError,
-    InsufficientScopeError, Mod)
+    InsufficientScopeError, Mod, GameMode)
 
 from tests import api
 
@@ -33,6 +33,12 @@ class TestBeatmap(TestCase):
     def test_deserialize(self):
         api.beatmap(beatmap_id=221777)
 
+        # beatmap with a diff owner
+        bm = api.beatmap(beatmap_id=1604098)
+        # might need to be updated when
+        # https://github.com/ppy/osu-web/issues/9784 is addressed.
+        self.assertIsNone(bm.owner)
+
 class TestBeatmapset(TestCase):
     def test_deserialize(self):
         api.beatmapset(beatmap_id=3207950)
@@ -156,6 +162,20 @@ class TestBeatmaps(TestCase):
     def test_deserialize(self):
         api.beatmaps([221777])
 
+class TestScore(TestCase):
+    def test_deserialize(self):
+        # downloadable
+        api.score(GameMode.OSU, 2243145877)
+        # downloadable, my score
+        api.score(GameMode.OSU, 3685255338)
+        # not downloadable, my score
+        api.score(GameMode.OSU, 3772000814)
+
+        # other gamemodes
+        api.score(GameMode.TAIKO, 176904666)
+        api.score(GameMode.MANIA, 524674141)
+        api.score(GameMode.CATCH, 211167989)
+
 # TODO requires friends.read scope
 # class TestFriends(TestCase):
 #     def test_deserialize(self):
